from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.compliance.client.v1 import client_pb2 as _client_pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as _method_options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetClientRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateClientRequest(_message.Message):
    __slots__ = ("client",)
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    client: _client_pb2.Client
    def __init__(self, client: _Optional[_Union[_client_pb2.Client, _Mapping]] = ...) -> None: ...

class ListClientsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListClientsResponse(_message.Message):
    __slots__ = ("clients",)
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    clients: _containers.RepeatedCompositeFieldContainer[_client_pb2.Client]
    def __init__(self, clients: _Optional[_Iterable[_Union[_client_pb2.Client, _Mapping]]] = ...) -> None: ...



"""Client v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .company_representative_role_pb2 import CompanyRepresentativeRole
from .identification_document_type_pb2 import IdentificationDocumentType
from .pep_status_pb2 import PepStatus
from .source_of_income_and_wealth_pb2 import SourceOfIncomeAndWealth
from .tax_residency_pb2 import TaxResidency
from .natural_person_pb2 import NaturalPerson
from .company_representative_pb2 import CompanyRepresentative
from .fund_pb2 import Fund
from .industry_classification_pb2 import IndustryClassification
from .trust_pb2 import Trust
from .company_pb2 import Company, ConnectedLegalPerson, LegalPersonConnectionType
from .verification_status_pb2 import VerificationStatus
from .client_pb2 import Client
from .natural_person_connection_type_pb2 import NaturalPersonConnectionType
from .service_pb2 import (
    CreateClientRequest,
    GetClientRequest,
    ListClientsRequest,
    ListClientsResponse,
)

# Generated service imports
from .service_meshpy import (
    ClientService,
    ClientServiceGRPCClient,
    ClientServiceGRPCClientInterface,
)

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "Client",
    "ClientService",
    "ClientServiceGRPCClient",
    "ClientServiceGRPCClientInterface",
    "Company",
    "CompanyRepresentative",
    "CompanyRepresentativeRole",
    "ConnectedLegalPerson",
    "CreateClientRequest",
    "Fund",
    "GetClientRequest",
    "IdentificationDocumentType",
    "IndustryClassification",
    "LegalPersonConnectionType",
    "ListClientsRequest",
    "ListClientsResponse",
    "NaturalPerson",
    "NaturalPersonConnectionType",
    "PepStatus",
    "SourceOfIncomeAndWealth",
    "TaxResidency",
    "Trust",
    "VerificationStatus",
]



"""User v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .user_pb2 import MobileNumber, User
from .service_pb2 import (
    AssignRolesToUserRequest,
    CreateUserRequest,
    GetUserByEmailRequest,
    GetUserRequest,
    ListUsersRequest,
    ListUsersResponse,
    RevokeRolesFromUserRequest,
    UpdateUserRequest,
)

# Generated service imports
from .service_meshpy import (
    UserService,
    UserServiceGRPCClient,
    UserServiceGRPCClientInterface,
)

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "AssignRolesToUserRequest",
    "CreateUserRequest",
    "GetUserByEmailRequest",
    "GetUserRequest",
    "ListUsersRequest",
    "ListUsersResponse",
    "MobileNumber",
    "RevokeRolesFromUserRequest",
    "UpdateUserRequest",
    "User",
    "UserService",
    "UserServiceGRPCClient",
    "UserServiceGRPCClientInterface",
]



"""Role utility functions for Mesh API.

This module provides helper functions for working with Role enums and their resource names.
All functions use the 4-part integer format: groups/{groupID}/roles/{roleNumber}
for cross-language compatibility.
"""

from meshtrade.iam.role.v1.role_pb2 import Role


def role_is_valid(role: Role) -> bool:
    """Check if role value is valid (within enum range).

    Args:
        role: Role enum value (integer)

    Returns:
        True if role is a valid enum value

    Example:
        >>> role_is_valid(Role.ROLE_IAM_ADMIN)
        True
        >>> role_is_valid(99999999)
        False
    """
    return role in Role.values()


def role_is_valid_and_specified(role: Role) -> bool:
    """Check if role is valid and not UNSPECIFIED.

    Args:
        role: Role enum value (integer)

    Returns:
        True if role is valid and not ROLE_UNSPECIFIED

    Example:
        >>> role_is_valid_and_specified(Role.ROLE_IAM_ADMIN)
        True
        >>> role_is_valid_and_specified(Role.ROLE_UNSPECIFIED)
        False
    """
    return role_is_valid(role) and role != Role.ROLE_UNSPECIFIED


def role_full_resource_name_from_group_id(role: Role, group_id: str) -> str:
    """Generate full resource name from role and group ID.

    Format: groups/{group_id}/roles/{role_int}

    Args:
        role: Role enum value (integer)
        group_id: Group ID (UUID)

    Returns:
        Full resource name string using integer format

    Example:
        >>> role_full_resource_name_from_group_id(Role.ROLE_IAM_ADMIN, "01DD32GZ7R0000000000000001")
        'groups/01DD32GZ7R0000000000000001/roles/3000000'
    """
    return f"groups/{group_id}/roles/{int(role)}"


def role_full_resource_name_from_group(role: Role, group: str) -> str:
    """Generate full resource name from role and group resource name.

    Args:
        role: Role enum value (integer)
        group: Group resource name (e.g., "groups/{id}")

    Returns:
        Full resource name string using integer format

    Raises:
        ValueError: If group format is invalid

    Example:
        >>> role_full_resource_name_from_group(Role.ROLE_IAM_ADMIN, "groups/01DD32GZ7R0000000000000001")
        'groups/01DD32GZ7R0000000000000001/roles/3000000'
    """
    if not group.startswith("groups/"):
        raise ValueError(f"invalid group format, expected groups/{{groupID}}, got: {group}")

    group_id = group[len("groups/") :]
    if not group_id:
        raise ValueError(f"group ID cannot be empty in group resource name: {group}")

    return role_full_resource_name_from_group_id(role, group_id)


def role_from_full_resource_name(full_resource_name: str) -> Role:
    """Extract Role from full resource name.

    Args:
        full_resource_name: Full resource name (e.g., "groups/{id}/roles/{role_int}")

    Returns:
        Role enum value (integer), or ROLE_UNSPECIFIED if parsing fails

    Example:
        >>> role_from_full_resource_name("groups/01DD32GZ7R0000000000000001/roles/3000000")
        3000000
        >>> role_from_full_resource_name("invalid/format")
        0
    """
    from typing import cast

    try:
        _, role_int = parse_role_parts(full_resource_name)
        # Python protobuf enums are integers, safe to cast
        return cast(Role, role_int)
    except ValueError:
        return Role.ROLE_UNSPECIFIED


def parse_role_parts(role_full_resource_name: str) -> tuple[str, int]:
    """Parse full resource name into group ID and Role.

    Expected format: groups/{group_id}/roles/{role_int}

    Args:
        role_full_resource_name: Full resource name

    Returns:
        Tuple of (group_id, role_int)

    Raises:
        ValueError: If format is invalid or role number cannot be parsed

    Example:
        >>> parse_role_parts("groups/01DD32GZ7R0000000000000001/roles/3000000")
        ('01DD32GZ7R0000000000000001', 3000000)
    """
    parts = role_full_resource_name.split("/")
    if len(parts) != 4 or parts[0] != "groups" or parts[2] != "roles":
        raise ValueError(f"invalid role format, expected groups/{{groupID}}/roles/{{role}}, got {role_full_resource_name}")

    group_id = parts[1]
    if not group_id:
        raise ValueError("group ID cannot be empty")

    try:
        role_int = int(parts[3])
    except ValueError as e:
        raise ValueError(f"error parsing role enum value '{parts[3]}'") from e

    if role_int < 0:
        raise ValueError(f"invalid role number in full resource name: {role_full_resource_name}")

    return group_id, role_int


def must_parse_role_parts(role_full_resource_name: str) -> tuple[str, int]:
    """Parse role parts, raising error on failure.

    This is an alias for parse_role_parts.
    Both functions raise ValueError on parsing errors.

    Args:
        role_full_resource_name: Full resource name

    Returns:
        Tuple of (group_id, role_int)

    Raises:
        ValueError: If format is invalid

    Example:
        >>> must_parse_role_parts("groups/01DD32GZ7R0000000000000001/roles/3000000")
        ('01DD32GZ7R0000000000000001', 3000000)
    """
    return parse_role_parts(role_full_resource_name)



"""Transaction state machine validation and transition logic.

This module provides state machine functions for transaction states and actions,
implementing the transaction lifecycle management logic.
"""

from meshtrade.ledger.transaction.v1.transaction_action_pb2 import TransactionAction
from meshtrade.ledger.transaction.v1.transaction_state_pb2 import TransactionState


def transaction_state_can_perform_action_at_state(state: TransactionState | None, action: TransactionAction | None) -> bool:
    """Check if the given action can be performed at the current transaction state.

    This implements the state machine logic for transaction lifecycle management.

    State Transitions:
    - DRAFT -> BUILD/COMMIT -> SIGNING_IN_PROGRESS
    - SIGNING_IN_PROGRESS -> SIGN/MARK_PENDING -> PENDING
    - PENDING -> SUBMIT -> SUBMISSION_IN_PROGRESS
    - SUBMISSION_IN_PROGRESS -> SUBMIT (retry) -> INDETERMINATE or SUCCESS/FAILED
    - INDETERMINATE -> SUBMIT (retry) -> SUCCESS/FAILED
    - FAILED/SUCCESSFUL -> No further actions allowed (terminal states)

    Args:
        state: The current TransactionState (can be None)
        action: The TransactionAction to perform (can be None)

    Returns:
        True if the action can be performed at the given state, False otherwise

    None Safety:
        Returns False if either state or action is None

    Example:
        >>> transaction_state_can_perform_action_at_state(
        ...     TransactionState.TRANSACTION_STATE_DRAFT,
        ...     TransactionAction.TRANSACTION_ACTION_BUILD
        ... )
        True
        >>> transaction_state_can_perform_action_at_state(
        ...     TransactionState.TRANSACTION_STATE_SUCCESSFUL,
        ...     TransactionAction.TRANSACTION_ACTION_SUBMIT
        ... )
        False
    """
    if state is None or action is None:
        return False

    if state == TransactionState.TRANSACTION_STATE_DRAFT:
        return action in {
            TransactionAction.TRANSACTION_ACTION_BUILD,
            TransactionAction.TRANSACTION_ACTION_COMMIT,
        }

    elif state == TransactionState.TRANSACTION_STATE_SIGNING_IN_PROGRESS:
        return action in {
            TransactionAction.TRANSACTION_ACTION_SIGN,
            TransactionAction.TRANSACTION_ACTION_MARK_PENDING,
        }

    elif state in {
        TransactionState.TRANSACTION_STATE_PENDING,
        TransactionState.TRANSACTION_STATE_SUBMISSION_IN_PROGRESS,
        TransactionState.TRANSACTION_STATE_INDETERMINATE,
    }:
        return action == TransactionAction.TRANSACTION_ACTION_SUBMIT

    elif state in {
        TransactionState.TRANSACTION_STATE_FAILED,
        TransactionState.TRANSACTION_STATE_SUCCESSFUL,
    }:
        return False

    else:
        return False



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/account_report/v1/income_entry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/account_report/v1/income_entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8meshtrade/reporting/account_report/v1/income_entry.proto\x12%meshtrade.reporting.account_report.v1\x1a\x1dmeshtrade/type/v1/token.proto\x1a\x1emeshtrade/type/v1/amount.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8a\x03\n\x0bIncomeEntry\x12\x1d\n\nasset_name\x18\x01 \x01(\tR\tassetName\x12.\n\x05token\x18\x02 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x05token\x12.\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x64\x61te\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12T\n\tnarrative\x18\x05 \x01(\x0e\x32\x36.meshtrade.reporting.account_report.v1.IncomeNarrativeR\tnarrative\x12\x31\n\x06\x61mount\x18\x06 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x06\x61mount\x12Q\n\x17reported_currency_value\x18\x07 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x15reportedCurrencyValue*\xfa\x01\n\x0fIncomeNarrative\x12 \n\x1cINCOME_NARRATIVE_UNSPECIFIED\x10\x00\x12\x1a\n\x16INCOME_NARRATIVE_YIELD\x10\x01\x12\x1d\n\x19INCOME_NARRATIVE_DIVIDEND\x10\x02\x12\x1d\n\x19INCOME_NARRATIVE_INTEREST\x10\x03\x12\x1e\n\x1aINCOME_NARRATIVE_PRINCIPAL\x10\x04\x12!\n\x1dINCOME_NARRATIVE_DISTRIBUTION\x10\x05\x12(\n$INCOME_NARRATIVE_PROFIT_DISTRIBUTION\x10\x06\x42y\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.account_report.v1.income_entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.reporting.account_report.v1ZIgithub.com/meshtrade/api/go/reporting/account_report/v1;account_report_v1'
  _globals['_INCOMENARRATIVE']._serialized_start=593
  _globals['_INCOMENARRATIVE']._serialized_end=843
  _globals['_INCOMEENTRY']._serialized_start=196
  _globals['_INCOMEENTRY']._serialized_end=590
# @@protoc_insertion_point(module_scope)



"""
API Credentials loading functionality for Meshtrade SDK.
"""

import json
import os
from pathlib import Path

import platformdirs

from .api_credentials_pb2 import APICredentials

MESH_API_CREDENTIALS_ENV_VAR = "MESH_API_CREDENTIALS"


def load_api_credentials_from_file(path: str) -> APICredentials:
    """Load API credentials from a JSON file.

    Args:
        path: Path to the credentials JSON file

    Returns:
        APICredentials object with loaded credentials

    Raises:
        FileNotFoundError: If the credentials file doesn't exist
        ValueError: If the credentials file is invalid or missing required fields
    """
    try:
        with open(path) as f:
            data = json.load(f)
    except FileNotFoundError as e:
        raise FileNotFoundError(f"Failed to read API credentials file: {path}") from e
    except json.JSONDecodeError as e:
        raise ValueError(f"Failed to parse API credentials file: {e}") from e

    api_key = data.get("api_key")
    group = data.get("group")

    if not api_key:
        raise ValueError("api_key is required in API credentials file")

    if not group:
        raise ValueError("group is required in API credentials file")

    if not group.startswith("groups/"):
        raise ValueError(f"group must be in format groups/{{group_id}}, got: {group}")

    creds = APICredentials()
    creds.api_key = api_key
    creds.group = group

    return creds


def api_credentials_from_environment() -> APICredentials | None:
    """Load API credentials from the file path specified in MESH_API_CREDENTIALS environment variable.

    Returns:
        APICredentials object if environment variable is set and file exists, None otherwise

    Raises:
        ValueError: If the credentials file is invalid
    """
    path = os.getenv(MESH_API_CREDENTIALS_ENV_VAR)
    if not path:
        return None

    return load_api_credentials_from_file(path)


def default_credentials_path() -> str:
    """
    Calculates the OS-specific default path for Mesh API credentials.

    This function determines the standard user configuration directory based on
    the operating system's conventions and returns the full path to the
    'credentials.json' file within a 'mesh' subdirectory. It is a Pythonic
    implementation of the equivalent Go function.

    The target path is constructed as follows:
    - **Linux**:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
    - **macOS**:   `$HOME/Library/Application Support/mesh/credentials.json`
    - **Windows**: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`

    Returns:
        A string representing the full, absolute path to the credentials file.
        If the user's home or config directory cannot be determined, it returns
        an empty string to match the original Go function's behavior.
    """
    try:
        # Use platformdirs to find the appropriate user config directory for the 'mesh' app.
        # This correctly handles all OS-specific paths and environment variables.
        # e.g., on Linux, it returns '~/.config/mesh'
        mesh_config_dir = platformdirs.user_config_dir(appname="mesh")

        # Use the modern `pathlib` to reliably construct the final file path.
        # The '/' operator is overloaded for joining path components.
        credentials_path = Path(mesh_config_dir) / "credentials.json"

        # Return the path as a string.
        return str(credentials_path)

    except Exception as e:
        # If platformdirs raises an error (e.g., HOME directory not found),
        # catch it and return an empty string, mimicking the Go function's
        # behavior on failure.
        print(f"Warning: Could not determine credentials path. Error: {e}")
        return ""


def load_default_credentials() -> APICredentials | None:
    """Load API credentials from the default location if the file exists.

    Returns:
        APICredentials object if default file exists and is valid, None otherwise

    Raises:
        ValueError: If the credentials file exists but is invalid
    """
    path = default_credentials_path()

    # Check if file exists before attempting to load
    if not os.path.isfile(path):
        return None

    return load_api_credentials_from_file(path)


def find_credentials() -> APICredentials | None:
    """Search for API credentials using the standard discovery hierarchy.

    Discovery order:
    1. MESH_API_CREDENTIALS environment variable (if set)
    2. Default credential file location
    - **Linux**:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
    - **macOS**:   `$HOME/Library/Application Support/mesh/credentials.json`
    - **Windows**: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`

    Returns:
        APICredentials object if found using any method, None if no credentials found

    Raises:
        ValueError: If a credentials file is found but is invalid
    """
    # Try environment variable first (existing behavior)
    creds = api_credentials_from_environment()
    if creds:
        return creds

    # Try default file location
    creds = load_default_credentials()
    if creds:
        return creds

    return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/company.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/company.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from meshtrade.compliance.client.v1 import company_representative_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_company__representative__pb2
from meshtrade.compliance.client.v1 import fund_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_fund__pb2
from meshtrade.compliance.client.v1 import industry_classification_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_industry__classification__pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_natural__person__pb2
from meshtrade.compliance.client.v1 import trust_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_trust__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.type.v1 import decimal_pb2 as meshtrade_dot_type_dot_v1_dot_decimal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,meshtrade/compliance/client/v1/company.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x16google/type/date.proto\x1a;meshtrade/compliance/client/v1/company_representative.proto\x1a)meshtrade/compliance/client/v1/fund.proto\x1a<meshtrade/compliance/client/v1/industry_classification.proto\x1a\x33meshtrade/compliance/client/v1/natural_person.proto\x1a*meshtrade/compliance/client/v1/trust.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\x1fmeshtrade/type/v1/decimal.proto\"\xc7\t\n\x07\x43ompany\x12\x31\n\x0fregistered_name\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01R\x0eregisteredName\x12\x38\n\x13registration_number\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x18\x64R\x12registrationNumber\x12.\n\x0etax_identifier\x18\x04 \x01(\tB\x07\xbaH\x04r\x02\x18\x32R\rtaxIdentifier\x12\xe3\x01\n\x18\x63ountry_of_incorporation\x18\x05 \x01(\tB\xa8\x01\xbaH\xa4\x01\xba\x01\xa0\x01\n\x1c\x63ountry_code.format.optional\x12Qcountry_of_incorporation must be empty or a valid ISO 3166-1 alpha-2 country code\x1a-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')R\x16\x63ountryOfIncorporation\x12\x45\n\x15\x64\x61te_of_incorporation\x18\x06 \x01(\x0b\x32\x11.google.type.DateR\x13\x64\x61teOfIncorporation\x12I\n\x12registered_address\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x11registeredAddress\x12X\n\x1aprincipal_physical_address\x18\x08 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x18principalPhysicalAddress\x12\x41\n\x0epostal_address\x18\t \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rpostalAddress\x12J\n\x13head_office_address\x18\n \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x11headOfficeAddress\x12n\n\x17\x63ompany_representatives\x18\x0b \x03(\x0b\x32\x35.meshtrade.compliance.client.v1.CompanyRepresentativeR\x16\x63ompanyRepresentatives\x12l\n\x17\x63onnected_legal_persons\x18\x0c \x03(\x0b\x32\x34.meshtrade.compliance.client.v1.ConnectedLegalPersonR\x15\x63onnectedLegalPersons\x12o\n\x17industry_classification\x18\r \x01(\x0b\x32\x36.meshtrade.compliance.client.v1.IndustryClassificationR\x16industryClassification\x12\x39\n\x14listed_exchange_code\x18\x0e \x01(\tB\x07\xbaH\x04r\x02\x18\x14R\x12listedExchangeCode\x12\x34\n\x11listing_reference\x18\x0f \x01(\tB\x07\xbaH\x04r\x02\x18\x14R\x10listingReference\"\x99\x05\n\x14\x43onnectedLegalPerson\x12V\n\x0enatural_person\x18\x01 \x01(\x0b\x32-.meshtrade.compliance.client.v1.NaturalPersonH\x00R\rnaturalPerson\x12\x43\n\x07\x63ompany\x18\x02 \x01(\x0b\x32\'.meshtrade.compliance.client.v1.CompanyH\x00R\x07\x63ompany\x12:\n\x04\x66und\x18\x03 \x01(\x0b\x32$.meshtrade.compliance.client.v1.FundH\x00R\x04\x66und\x12=\n\x05trust\x18\x04 \x01(\x0b\x32%.meshtrade.compliance.client.v1.TrustH\x00R\x05trust\x12s\n\x10\x63onnection_types\x18\x05 \x03(\x0e\x32\x39.meshtrade.compliance.client.v1.LegalPersonConnectionTypeB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x0f\x63onnectionTypes\x12M\n\x14ownership_percentage\x18\x06 \x01(\x0b\x32\x1a.meshtrade.type.v1.DecimalR\x13ownershipPercentage\x12T\n\x18voting_rights_percentage\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.DecimalR\x16votingRightsPercentage\x12?\n\x16\x63onnection_description\x18\x08 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03R\x15\x63onnectionDescriptionB\x0e\n\x0clegal_person*\xe3\x02\n\x19LegalPersonConnectionType\x12,\n(LEGAL_PERSON_CONNECTION_TYPE_UNSPECIFIED\x10\x00\x12,\n(LEGAL_PERSON_CONNECTION_TYPE_SHAREHOLDER\x10\x01\x12/\n+LEGAL_PERSON_CONNECTION_TYPE_PARENT_COMPANY\x10\x02\x12\x33\n/LEGAL_PERSON_CONNECTION_TYPE_CORPORATE_DIRECTOR\x10\x03\x12&\n\"LEGAL_PERSON_CONNECTION_TYPE_TRUST\x10\x04\x12\x30\n,LEGAL_PERSON_CONNECTION_TYPE_GENERAL_PARTNER\x10\x05\x12*\n&LEGAL_PERSON_CONNECTION_TYPE_GUARANTOR\x10\x06\x42\x63\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.company_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_COMPANY'].fields_by_name['registered_name']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['registered_name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_COMPANY'].fields_by_name['registration_number']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['registration_number']._serialized_options = b'\272H\004r\002\030d'
  _globals['_COMPANY'].fields_by_name['tax_identifier']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['tax_identifier']._serialized_options = b'\272H\004r\002\0302'
  _globals['_COMPANY'].fields_by_name['country_of_incorporation']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['country_of_incorporation']._serialized_options = b'\272H\244\001\272\001\240\001\n\034country_code.format.optional\022Qcountry_of_incorporation must be empty or a valid ISO 3166-1 alpha-2 country code\032-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')'
  _globals['_COMPANY'].fields_by_name['listed_exchange_code']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['listed_exchange_code']._serialized_options = b'\272H\004r\002\030\024'
  _globals['_COMPANY'].fields_by_name['listing_reference']._loaded_options = None
  _globals['_COMPANY'].fields_by_name['listing_reference']._serialized_options = b'\272H\004r\002\030\024'
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_types']._loaded_options = None
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_types']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_description']._loaded_options = None
  _globals['_CONNECTEDLEGALPERSON'].fields_by_name['connection_description']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_LEGALPERSONCONNECTIONTYPE']._serialized_start=2357
  _globals['_LEGALPERSONCONNECTIONTYPE']._serialized_end=2712
  _globals['_COMPANY']._serialized_start=463
  _globals['_COMPANY']._serialized_end=1686
  _globals['_CONNECTEDLEGALPERSON']._serialized_start=1689
  _globals['_CONNECTEDLEGALPERSON']._serialized_end=2354
# @@protoc_insertion_point(module_scope)



# Code generated by protoc-gen-meshpy. DO NOT EDIT.
# source: meshtrade/iam/user/v1/service.proto

"""
UserService gRPC service wrapper with authentication, timeouts, and resource management.

This module provides a high-level gRPC service for the UserService service that combines
the service interface with resource management capabilities, providing authentication,
timeouts, and proper connection handling.
"""

from collections.abc import Iterator
from datetime import timedelta
from typing import Optional

from meshtrade.common import BaseGRPCClient
from meshtrade.iam.api_user.v1.api_credentials import find_credentials

from .user_pb2 import User
from meshtrade.common.service_options import ServiceOptions
from .service_pb2 import (
AssignRolesToUserRequest,
CreateUserRequest,
GetUserByEmailRequest,
GetUserRequest,
ListUsersRequest,
ListUsersResponse,
RevokeRolesFromUserRequest,
UpdateUserRequest,
)
from .service_pb2_grpc import UserServiceStub


def _create_userservice_stub(channel):
    """Factory function to create UserServiceStub from gRPC channel."""
    return UserServiceStub(channel)


class UserService(BaseGRPCClient):
    """UserService gRPC service with authentication, timeouts, and resource management.

    This service provides a complete implementation of the UserService with proper authentication, timeout handling, and automatic resource cleanup.

    Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/iam/user/v1

    Basic service usage with default SDK Configuration:
    ```python
    service = UserService()

    with service:   # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```
        
    With default configuration API credentials are searched for using the standard discovery hierarchy:
    
    1. MESH_API_CREDENTIALS environment variable
    
    2. Default credential file location:
    
    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`
    
    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

    The service may also be configured with custom options:
    ```python
    from .service_options_meshpy import ServiceOptions
    from datetime import timedelta

    options = ServiceOptions(
        url="api.staging.example.com",
        port=443,
        api_key="your-api-key",
        group="groups/your-group-id",
        timeout=timedelta(seconds=60)
    )

    service = UserService(options)

    with service: # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```

    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration
    """

    def __init__(self, options: Optional[ServiceOptions] = None):
        """Construct and initialize the UserService service.

        Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/iam/user/v1

        Args:
            options: Optional ServiceOptions for configuring the service.
                    If None, service is constructed with default configuration.
                    With default configuration API credentials are searched for using the standard discovery hierarchy:
                    
                    1. MESH_API_CREDENTIALS environment variable
                    
                    2. Default credential file location:
                    
                    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
                    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
                    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`      

                    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

                    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration            

        Example:
        ```python
        # construct with default configuration
        service = UserService()

        # construct with custom configuration
        options = ServiceOptions(
            url="api.example.com",
            api_key="your-key",
            group="groups/your-group"
        )
        service = UserService(options)
        ```
        """
        if options is None:
            options = ServiceOptions()

        # Initialize the base client with all common functionality
        super().__init__(
            service_name="UserService",
            stub_factory=_create_userservice_stub,
            find_credentials_func=find_credentials,
            url=options.url,
            port=options.port,
            api_key=options.api_key,
            group=options.group,
            timeout=options.timeout,
            tls=options.tls,
        )

    def assign_roles_to_user(self, request: AssignRolesToUserRequest, timeout: Optional[timedelta] = None) -> User:
        """AssignRolesToUser method.

        Args:
            request: The AssignRolesToUser request message
            timeout: Optional timeout override for this call

        Returns:
            The AssignRolesToUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("AssignRolesToUser", request, timeout)

    def revoke_roles_from_user(self, request: RevokeRolesFromUserRequest, timeout: Optional[timedelta] = None) -> User:
        """RevokeRolesFromUser method.

        Args:
            request: The RevokeRolesFromUser request message
            timeout: Optional timeout override for this call

        Returns:
            The RevokeRolesFromUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("RevokeRolesFromUser", request, timeout)

    def get_user(self, request: GetUserRequest, timeout: Optional[timedelta] = None) -> User:
        """GetUser method.

        Args:
            request: The GetUser request message
            timeout: Optional timeout override for this call

        Returns:
            The GetUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("GetUser", request, timeout)

    def get_user_by_email(self, request: GetUserByEmailRequest, timeout: Optional[timedelta] = None) -> User:
        """GetUserByEmail method.

        Args:
            request: The GetUserByEmail request message
            timeout: Optional timeout override for this call

        Returns:
            The GetUserByEmail response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("GetUserByEmail", request, timeout)

    def list_users(self, request: ListUsersRequest, timeout: Optional[timedelta] = None) -> ListUsersResponse:
        """ListUsers method.

        Args:
            request: The ListUsers request message
            timeout: Optional timeout override for this call

        Returns:
            The ListUsers response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("ListUsers", request, timeout)

    def create_user(self, request: CreateUserRequest, timeout: Optional[timedelta] = None) -> User:
        """CreateUser method.

        Args:
            request: The CreateUser request message
            timeout: Optional timeout override for this call

        Returns:
            The CreateUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("CreateUser", request, timeout)

    def update_user(self, request: UpdateUserRequest, timeout: Optional[timedelta] = None) -> User:
        """UpdateUser method.

        Args:
            request: The UpdateUser request message
            timeout: Optional timeout override for this call

        Returns:
            The UpdateUser response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("UpdateUser", request, timeout)


# Create aliases to match expected exports
UserServiceGRPCClient = UserService
UserServiceGRPCClientInterface = UserService



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionAction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TRANSACTION_ACTION_UNSPECIFIED: _ClassVar[TransactionAction]
    TRANSACTION_ACTION_DO_NOTHING: _ClassVar[TransactionAction]
    TRANSACTION_ACTION_BUILD: _ClassVar[TransactionAction]
    TRANSACTION_ACTION_COMMIT: _ClassVar[TransactionAction]
    TRANSACTION_ACTION_SIGN: _ClassVar[TransactionAction]
    TRANSACTION_ACTION_MARK_PENDING: _ClassVar[TransactionAction]
    TRANSACTION_ACTION_SUBMIT: _ClassVar[TransactionAction]
TRANSACTION_ACTION_UNSPECIFIED: TransactionAction
TRANSACTION_ACTION_DO_NOTHING: TransactionAction
TRANSACTION_ACTION_BUILD: TransactionAction
TRANSACTION_ACTION_COMMIT: TransactionAction
TRANSACTION_ACTION_SIGN: TransactionAction
TRANSACTION_ACTION_MARK_PENDING: TransactionAction
TRANSACTION_ACTION_SUBMIT: TransactionAction



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.trading.limit_order.v1 import limit_order_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2
from meshtrade.trading.limit_order.v1 import service_pb2 as meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2


class LimitOrderServiceStub(object):
    """
    LimitOrderService manages limit orders for trading operations (BETA).

    This service provides comprehensive limit order management capabilities including
    order creation, cancellation, querying, and real-time monitoring. All operations
    are scoped to the authenticated group's hierarchy and require appropriate trading
    domain permissions.

    Note: This service is currently in BETA. Interface and functionality may change.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateLimitOrder = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/CreateLimitOrder',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.CreateLimitOrderRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
                _registered_method=True)
        self.CancelLimitOrder = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/CancelLimitOrder',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.CancelLimitOrderRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
                _registered_method=True)
        self.GetLimitOrder = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrder',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
                _registered_method=True)
        self.GetLimitOrderByExternalReference = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrderByExternalReference',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderByExternalReferenceRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
                _registered_method=True)
        self.ListLimitOrders = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/ListLimitOrders',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.ListLimitOrdersRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.ListLimitOrdersResponse.FromString,
                _registered_method=True)
        self.SearchLimitOrders = channel.unary_unary(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/SearchLimitOrders',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.SearchLimitOrdersRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.SearchLimitOrdersResponse.FromString,
                _registered_method=True)
        self.MonitorLimitOrder = channel.unary_stream(
                '/meshtrade.trading.limit_order.v1.LimitOrderService/MonitorLimitOrder',
                request_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.MonitorLimitOrderRequest.SerializeToString,
                response_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
                _registered_method=True)


class LimitOrderServiceServicer(object):
    """
    LimitOrderService manages limit orders for trading operations (BETA).

    This service provides comprehensive limit order management capabilities including
    order creation, cancellation, querying, and real-time monitoring. All operations
    are scoped to the authenticated group's hierarchy and require appropriate trading
    domain permissions.

    Note: This service is currently in BETA. Interface and functionality may change.
    """

    def CreateLimitOrder(self, request, context):
        """
        Creates a new limit order.

        Submits a limit order to the trading system. The order is validated and
        submitted to the appropriate ledger for execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelLimitOrder(self, request, context):
        """
        Cancels an existing limit order.

        Initiates cancellation of a limit order on the ledger.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLimitOrder(self, request, context):
        """
        Retrieves a specific limit order by its resource name.

        Provides access to limit order metadata and optionally fetches live
        ledger data when populate_ledger_data is true.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLimitOrderByExternalReference(self, request, context):
        """
        Retrieves a limit order by its external reference.

        Convenient lookup using client-provided external reference identifier.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLimitOrders(self, request, context):
        """
        Lists all limit orders within the authenticated group's scope.

        Returns the complete set of limit orders accessible to the executing context.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchLimitOrders(self, request, context):
        """
        Searches limit orders using flexible filtering criteria.

        Supports filtering by token, account, and populating live ledger data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MonitorLimitOrder(self, request, context):
        """
        Monitors a limit order for real-time updates.

        Supports lookup by either resource name or external reference using
        the identifier oneof field in the request. Returns a stream of limit
        order states as they change.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LimitOrderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLimitOrder,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.CreateLimitOrderRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.SerializeToString,
            ),
            'CancelLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelLimitOrder,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.CancelLimitOrderRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.SerializeToString,
            ),
            'GetLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLimitOrder,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.SerializeToString,
            ),
            'GetLimitOrderByExternalReference': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLimitOrderByExternalReference,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderByExternalReferenceRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.SerializeToString,
            ),
            'ListLimitOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLimitOrders,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.ListLimitOrdersRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.ListLimitOrdersResponse.SerializeToString,
            ),
            'SearchLimitOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchLimitOrders,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.SearchLimitOrdersRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.SearchLimitOrdersResponse.SerializeToString,
            ),
            'MonitorLimitOrder': grpc.unary_stream_rpc_method_handler(
                    servicer.MonitorLimitOrder,
                    request_deserializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.MonitorLimitOrderRequest.FromString,
                    response_serializer=meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.trading.limit_order.v1.LimitOrderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.trading.limit_order.v1.LimitOrderService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class LimitOrderService(object):
    """
    LimitOrderService manages limit orders for trading operations (BETA).

    This service provides comprehensive limit order management capabilities including
    order creation, cancellation, querying, and real-time monitoring. All operations
    are scoped to the authenticated group's hierarchy and require appropriate trading
    domain permissions.

    Note: This service is currently in BETA. Interface and functionality may change.
    """

    @staticmethod
    def CreateLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/CreateLimitOrder',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.CreateLimitOrderRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/CancelLimitOrder',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.CancelLimitOrderRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrder',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLimitOrderByExternalReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/GetLimitOrderByExternalReference',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.GetLimitOrderByExternalReferenceRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListLimitOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/ListLimitOrders',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.ListLimitOrdersRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.ListLimitOrdersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchLimitOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/SearchLimitOrders',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.SearchLimitOrdersRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.SearchLimitOrdersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MonitorLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/meshtrade.trading.limit_order.v1.LimitOrderService/MonitorLimitOrder',
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_service__pb2.MonitorLimitOrderRequest.SerializeToString,
            meshtrade_dot_trading_dot_limit__order_dot_v1_dot_limit__order__pb2.LimitOrder.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
This module provides helper functions for working with Date protobuf messages.
"""

from datetime import date as python_date
from datetime import datetime

from .date_pb2 import Date


def new_date(year: int, month: int, day: int) -> Date:
    """Creates a new Date from year, month, and day values.

    Args:
        year: Year value (1-9999)
        month: Month value (1-12)
        day: Day value (1-31)

    Returns:
        A Date protobuf message

    Raises:
        ValueError: If the date values are invalid
    """
    _validate_date(year, month, day)
    return Date(year=year, month=month, day=day)


def new_date_from_python_date(python_date_obj: python_date) -> Date:
    """Creates a Date from a Python date object.

    Args:
        python_date_obj: A Python datetime.date object

    Returns:
        A Date protobuf message
    """
    return Date(year=python_date_obj.year, month=python_date_obj.month, day=python_date_obj.day)


def new_date_from_datetime(datetime_obj: datetime) -> Date:
    """Creates a Date from a Python datetime object.
    Only extracts the date components, ignoring the time.

    Args:
        datetime_obj: A Python datetime.datetime object

    Returns:
        A Date protobuf message
    """
    return new_date_from_python_date(datetime_obj.date())


def date_to_python_date(date_obj: Date) -> python_date:
    """Converts a Date protobuf message to a Python date object.

    Args:
        date_obj: A Date protobuf message

    Returns:
        A Python datetime.date object

    Raises:
        ValueError: If the date is invalid
    """
    if not date_obj:
        raise ValueError("Date object is None")

    if not date_is_valid(date_obj):
        raise ValueError(f"Invalid date: year={date_obj.year}, month={date_obj.month}, day={date_obj.day}")

    try:
        return python_date(date_obj.year, date_obj.month, date_obj.day)
    except ValueError as e:
        raise ValueError(f"Invalid date values: {e}") from e


def date_is_valid(date_obj: Date | None) -> bool:
    """Checks if a Date has valid values according to the protobuf constraints.

    Args:
        date_obj: A Date protobuf message or None

    Returns:
        True if the date is valid, False otherwise
    """
    if not date_obj:
        return False

    try:
        _validate_date(date_obj.year, date_obj.month, date_obj.day)
        return True
    except ValueError:
        return False


def date_is_complete(date_obj: Date | None) -> bool:
    """Returns True if the date has non-zero year, month, and day values.
    Since only full dates are valid, this is equivalent to is_valid().

    Args:
        date_obj: A Date protobuf message or None

    Returns:
        True if the date is complete, False otherwise
    """
    if not date_obj:
        return False
    return date_obj.year != 0 and date_obj.month != 0 and date_obj.day != 0


def date_to_string(date_obj: Date | None) -> str:
    """Returns a string representation of the date.

    Args:
        date_obj: A Date protobuf message or None

    Returns:
        String representation of the date
    """
    if not date_obj:
        return "<undefined>"

    if date_is_valid(date_obj):
        return f"{date_obj.year:04d}-{date_obj.month:02d}-{date_obj.day:02d}"
    else:
        return f"Date(year={date_obj.year}, month={date_obj.month}, day={date_obj.day}) [INVALID]"


def date_is_before(date1: Date | None, date2: Date | None) -> bool:
    """Returns True if date1 is before date2.

    Args:
        date1: First Date protobuf message or None
        date2: Second Date protobuf message or None

    Returns:
        True if date1 is before date2, False otherwise

    Raises:
        ValueError: If either date is None or incomplete
    """
    if not date1 or not date2:
        raise ValueError("Both dates must be provided")

    if not date_is_valid(date1) or not date_is_valid(date2):
        raise ValueError("Both dates must be valid for comparison")

    # Compare year first
    if date1.year != date2.year:
        return date1.year < date2.year

    # Compare month if years are equal
    if date1.month != date2.month:
        return date1.month < date2.month

    # Compare day if years and months are equal
    return date1.day < date2.day


def date_is_after(date1: Date | None, date2: Date | None) -> bool:
    """Returns True if date1 is after date2.

    Args:
        date1: First Date protobuf message or None
        date2: Second Date protobuf message or None

    Returns:
        True if date1 is after date2, False otherwise

    Raises:
        ValueError: If either date is None or incomplete
    """
    if not date1 or not date2:
        raise ValueError("Both dates must be provided")

    if not date_is_valid(date1) or not date_is_valid(date2):
        raise ValueError("Both dates must be valid for comparison")

    # Compare year first
    if date1.year != date2.year:
        return date1.year > date2.year

    # Compare month if years are equal
    if date1.month != date2.month:
        return date1.month > date2.month

    # Compare day if years and months are equal
    return date1.day > date2.day


def date_is_equal(date1: Date | None, date2: Date | None) -> bool:
    """Returns True if date1 is equal to date2.

    Args:
        date1: First Date protobuf message or None
        date2: Second Date protobuf message or None

    Returns:
        True if date1 is equal to date2, False otherwise
    """
    if not date1 and not date2:
        return True

    if not date1 or not date2:
        return False

    return date1.year == date2.year and date1.month == date2.month and date1.day == date2.day


def date_is_before_or_equal(date1: Date | None, date2: Date | None) -> bool:
    """Returns True if date1 is before or equal to date2.

    Args:
        date1: First Date protobuf message or None
        date2: Second Date protobuf message or None

    Returns:
        True if date1 is before or equal to date2, False otherwise

    Raises:
        ValueError: If either date is None or incomplete
    """
    return date_is_before(date1, date2) or date_is_equal(date1, date2)


def date_is_after_or_equal(date1: Date | None, date2: Date | None) -> bool:
    """Returns True if date1 is after or equal to date2.

    Args:
        date1: First Date protobuf message or None
        date2: Second Date protobuf message or None

    Returns:
        True if date1 is after or equal to date2, False otherwise

    Raises:
        ValueError: If either date is None or incomplete
    """
    return date_is_after(date1, date2) or date_is_equal(date1, date2)


def date_add_days(date_obj: Date, days: int) -> Date:
    """Adds a specified number of days to a date.

    Args:
        date_obj: A Date protobuf message
        days: Number of days to add (can be negative to subtract)

    Returns:
        A new Date protobuf message with the days added

    Raises:
        ValueError: If the date is None or incomplete
    """
    if not date_obj:
        raise ValueError("Date object is None")

    if not date_is_valid(date_obj):
        raise ValueError("Date must be valid to add days")

    # Convert to Python date, add days, then convert back
    py_date = date_to_python_date(date_obj)
    from datetime import timedelta

    new_py_date = py_date + timedelta(days=days)

    return new_date_from_python_date(new_py_date)


def date_add_months(date_obj: Date, months: int) -> Date:
    """Adds a specified number of months to a date.

    Args:
        date_obj: A Date protobuf message
        months: Number of months to add (can be negative to subtract)

    Returns:
        A new Date protobuf message with the months added

    Raises:
        ValueError: If the date is None or incomplete, or if the result is invalid
    """
    if not date_obj:
        raise ValueError("Date object is None")

    if not date_is_valid(date_obj):
        raise ValueError("Date must be valid to add months")

    # Calculate new year and month
    total_months = date_obj.year * 12 + date_obj.month - 1 + months
    new_year = total_months // 12
    new_month = (total_months % 12) + 1

    # Validate that the resulting year is within valid range
    if new_year < 1 or new_year > 9999:
        raise ValueError(f"Resulting year {new_year} is outside valid range [1, 9999]")

    # Handle day overflow (e.g., Jan 31 + 1 month should be Feb 28/29)
    new_day = date_obj.day

    # Check if the day is valid for the new month
    import calendar

    max_day = calendar.monthrange(new_year, new_month)[1]
    if new_day > max_day:
        new_day = max_day

    return new_date(new_year, new_month, new_day)


def date_add_years(date_obj: Date, years: int) -> Date:
    """Adds a specified number of years to a date.

    Args:
        date_obj: A Date protobuf message
        years: Number of years to add (can be negative to subtract)

    Returns:
        A new Date protobuf message with the years added

    Raises:
        ValueError: If the date is None or incomplete, or if the result is invalid
    """
    if not date_obj:
        raise ValueError("Date object is None")

    if not date_is_valid(date_obj):
        raise ValueError("Date must be valid to add years")

    new_year = date_obj.year + years
    new_month = date_obj.month
    new_day = date_obj.day

    # Handle leap year edge case (Feb 29 + 1 year when next year is not leap)
    if new_month == 2 and new_day == 29:
        import calendar

        if not calendar.isleap(new_year):
            new_day = 28

    return new_date(new_year, new_month, new_day)


def _validate_date(year: int, month: int, day: int) -> None:
    """Validates the year, month, and day values according to Date constraints.
    Only full dates are valid - all fields must be non-zero.

    Args:
        year: Year value
        month: Month value
        day: Day value

    Raises:
        ValueError: If the date values are invalid
    """
    # Year validation - must be non-zero
    if year < 1 or year > 9999:
        raise ValueError(f"Year must be between 1 and 9999, got {year}")

    # Month validation - must be non-zero
    if month < 1 or month > 12:
        raise ValueError(f"Month must be between 1 and 12, got {month}")

    # Day validation - must be non-zero
    if day < 1 or day > 31:
        raise ValueError(f"Day must be between 1 and 31, got {day}")

    # Check if the day is valid for the given month and year
    try:
        python_date(year, month, day)
    except ValueError as e:
        raise ValueError(f"Invalid date: {year}-{month:02d}-{day:02d}: {e}") from e



# Code generated by protoc-gen-meshpy. DO NOT EDIT.
# source: meshtrade/ledger/transaction/v1/service.proto

"""
TransactionService gRPC service wrapper with authentication, timeouts, and resource management.

This module provides a high-level gRPC service for the TransactionService service that combines
the service interface with resource management capabilities, providing authentication,
timeouts, and proper connection handling.
"""

from collections.abc import Iterator
from datetime import timedelta
from typing import Optional

from meshtrade.common import BaseGRPCClient
from meshtrade.iam.api_user.v1.api_credentials import find_credentials

from meshtrade.common.service_options import ServiceOptions
from .service_pb2 import (
GetTransactionStateRequest,
GetTransactionStateResponse,
MonitorTransactionStateRequest,
MonitorTransactionStateResponse,
)
from .service_pb2_grpc import TransactionServiceStub


def _create_transactionservice_stub(channel):
    """Factory function to create TransactionServiceStub from gRPC channel."""
    return TransactionServiceStub(channel)


class TransactionService(BaseGRPCClient):
    """TransactionService gRPC service with authentication, timeouts, and resource management.

    This service provides a complete implementation of the TransactionService with proper authentication, timeout handling, and automatic resource cleanup.

    Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/ledger/transaction/v1

    Basic service usage with default SDK Configuration:
    ```python
    service = TransactionService()

    with service:   # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```
        
    With default configuration API credentials are searched for using the standard discovery hierarchy:
    
    1. MESH_API_CREDENTIALS environment variable
    
    2. Default credential file location:
    
    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`
    
    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

    The service may also be configured with custom options:
    ```python
    from .service_options_meshpy import ServiceOptions
    from datetime import timedelta

    options = ServiceOptions(
        url="api.staging.example.com",
        port=443,
        api_key="your-api-key",
        group="groups/your-group-id",
        timeout=timedelta(seconds=60)
    )

    service = TransactionService(options)

    with service: # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```

    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration
    """

    def __init__(self, options: Optional[ServiceOptions] = None):
        """Construct and initialize the TransactionService service.

        Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/ledger/transaction/v1

        Args:
            options: Optional ServiceOptions for configuring the service.
                    If None, service is constructed with default configuration.
                    With default configuration API credentials are searched for using the standard discovery hierarchy:
                    
                    1. MESH_API_CREDENTIALS environment variable
                    
                    2. Default credential file location:
                    
                    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
                    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
                    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`      

                    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

                    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration            

        Example:
        ```python
        # construct with default configuration
        service = TransactionService()

        # construct with custom configuration
        options = ServiceOptions(
            url="api.example.com",
            api_key="your-key",
            group="groups/your-group"
        )
        service = TransactionService(options)
        ```
        """
        if options is None:
            options = ServiceOptions()

        # Initialize the base client with all common functionality
        super().__init__(
            service_name="TransactionService",
            stub_factory=_create_transactionservice_stub,
            find_credentials_func=find_credentials,
            url=options.url,
            port=options.port,
            api_key=options.api_key,
            group=options.group,
            timeout=options.timeout,
            tls=options.tls,
        )

    def get_transaction_state(self, request: GetTransactionStateRequest, timeout: Optional[timedelta] = None) -> GetTransactionStateResponse:
        """GetTransactionState method.

        Args:
            request: The GetTransactionState request message
            timeout: Optional timeout override for this call

        Returns:
            The GetTransactionState response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("GetTransactionState", request, timeout)

    def monitor_transaction_state(self, request: MonitorTransactionStateRequest, timeout: Optional[timedelta] = None) -> Iterator[MonitorTransactionStateResponse]:
        """MonitorTransactionState server-side streaming method with authentication and validation.

        Args:
            request: The MonitorTransactionState request message
            timeout: Optional timeout override for this call

        Yields:
            MonitorTransactionStateResponse: Stream of response messages

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing or request validation fails

        Example:
            >>> stream = service.monitor_transaction_state(request)
            >>> for response in stream:
            ...     # Process each response
            ...     print(response)
        """
        return self._execute_streaming_method("MonitorTransactionState", request, timeout)


# Create aliases to match expected exports
TransactionServiceGRPCClient = TransactionService
TransactionServiceGRPCClientInterface = TransactionService



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/api_user/v1/api_credentials.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/api_user/v1/api_credentials.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/meshtrade/iam/api_user/v1/api_credentials.proto\x12\x19meshtrade.iam.api_user.v1\x1a\x1b\x62uf/validate/validate.proto\"\xb0\x03\n\x0e\x41PICredentials\x12\x39\n\x07\x61pi_key\x18\x01 \x01(\tB \xbaH\x1dr\x18\x32\x13^[A-Za-z0-9_-]{43}$\x98\x01+\xc8\x01\x01R\x06\x61piKey\x12\xe2\x02\n\x05group\x18\x02 \x01(\tB\xcb\x02\xbaH\xc7\x02r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xba\x01Y\n\x0egroup.required\x12\x35group is required and must be in format groups/{ulid}\x1a\x10size(this) == 33\xba\x01\xb1\x01\n\x0cgroup.format\x12`group must be in format groups/{ulid} where ulid is a 26-character ULID (uppercase alphanumeric)\x1a?this.matches(\'^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x05groupB[\n co.meshtrade.api.iam.api_user.v1Z7github.com/meshtrade/api/go/iam/api_user/v1;api_user_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.api_user.v1.api_credentials_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n co.meshtrade.api.iam.api_user.v1Z7github.com/meshtrade/api/go/iam/api_user/v1;api_user_v1'
  _globals['_APICREDENTIALS'].fields_by_name['api_key']._loaded_options = None
  _globals['_APICREDENTIALS'].fields_by_name['api_key']._serialized_options = b'\272H\035r\0302\023^[A-Za-z0-9_-]{43}$\230\001+\310\001\001'
  _globals['_APICREDENTIALS'].fields_by_name['group']._loaded_options = None
  _globals['_APICREDENTIALS'].fields_by_name['group']._serialized_options = b'\272H\307\002r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\272\001Y\n\016group.required\0225group is required and must be in format groups/{ulid}\032\020size(this) == 33\272\001\261\001\n\014group.format\022`group must be in format groups/{ulid} where ulid is a 26-character ULID (uppercase alphanumeric)\032?this.matches(\'^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_APICREDENTIALS']._serialized_start=108
  _globals['_APICREDENTIALS']._serialized_end=540
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class NaturalPersonConnectionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NATURAL_PERSON_CONNECTION_TYPE_UNSPECIFIED: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_ULTIMATE_BENEFICIAL_OWNER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SHAREHOLDER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_DIRECTOR: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SENIOR_MANAGEMENT: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_AUTHORIZED_SIGNATORY: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_FOUNDER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SPOUSE: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_DOMESTIC_PARTNER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_PARENT: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_CHILD: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_SIBLING: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_BUSINESS_PARTNER: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_CLOSE_ASSOCIATE: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_GUARANTOR: _ClassVar[NaturalPersonConnectionType]
    NATURAL_PERSON_CONNECTION_TYPE_BENEFICIARY_OF_TRUST: _ClassVar[NaturalPersonConnectionType]
NATURAL_PERSON_CONNECTION_TYPE_UNSPECIFIED: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_ULTIMATE_BENEFICIAL_OWNER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SHAREHOLDER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_DIRECTOR: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SENIOR_MANAGEMENT: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_AUTHORIZED_SIGNATORY: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_FOUNDER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SPOUSE: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_DOMESTIC_PARTNER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_PARENT: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_CHILD: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_SIBLING: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_BUSINESS_PARTNER: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_CLOSE_ASSOCIATE: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_GUARANTOR: NaturalPersonConnectionType
NATURAL_PERSON_CONNECTION_TYPE_BENEFICIARY_OF_TRUST: NaturalPersonConnectionType



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TimeOfDay(_message.Message):
    __slots__ = ("hours", "minutes", "seconds", "nanos")
    HOURS_FIELD_NUMBER: _ClassVar[int]
    MINUTES_FIELD_NUMBER: _ClassVar[int]
    SECONDS_FIELD_NUMBER: _ClassVar[int]
    NANOS_FIELD_NUMBER: _ClassVar[int]
    hours: int
    minutes: int
    seconds: int
    nanos: int
    def __init__(self, hours: _Optional[int] = ..., minutes: _Optional[int] = ..., seconds: _Optional[int] = ..., nanos: _Optional[int] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.type import date_pb2 as _date_pb2
from meshtrade.compliance.client.v1 import identification_document_type_pb2 as _identification_document_type_pb2
from meshtrade.compliance.client.v1 import pep_status_pb2 as _pep_status_pb2
from meshtrade.compliance.client.v1 import source_of_income_and_wealth_pb2 as _source_of_income_and_wealth_pb2
from meshtrade.compliance.client.v1 import tax_residency_pb2 as _tax_residency_pb2
from meshtrade.type.v1 import address_pb2 as _address_pb2
from meshtrade.type.v1 import contact_details_pb2 as _contact_details_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NaturalPerson(_message.Message):
    __slots__ = ("full_name", "date_of_birth", "country_of_citizenship", "identification_number", "identification_document_type", "identification_document_expiry_date", "physical_address", "postal_address", "pep_status", "contact_details", "sources_of_income", "sources_of_wealth", "tax_residencies")
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    DATE_OF_BIRTH_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_OF_CITIZENSHIP_FIELD_NUMBER: _ClassVar[int]
    IDENTIFICATION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    IDENTIFICATION_DOCUMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    IDENTIFICATION_DOCUMENT_EXPIRY_DATE_FIELD_NUMBER: _ClassVar[int]
    PHYSICAL_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    POSTAL_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PEP_STATUS_FIELD_NUMBER: _ClassVar[int]
    CONTACT_DETAILS_FIELD_NUMBER: _ClassVar[int]
    SOURCES_OF_INCOME_FIELD_NUMBER: _ClassVar[int]
    SOURCES_OF_WEALTH_FIELD_NUMBER: _ClassVar[int]
    TAX_RESIDENCIES_FIELD_NUMBER: _ClassVar[int]
    full_name: str
    date_of_birth: _date_pb2.Date
    country_of_citizenship: str
    identification_number: str
    identification_document_type: _identification_document_type_pb2.IdentificationDocumentType
    identification_document_expiry_date: _date_pb2.Date
    physical_address: _address_pb2.Address
    postal_address: _address_pb2.Address
    pep_status: _pep_status_pb2.PepStatus
    contact_details: _contact_details_pb2.ContactDetails
    sources_of_income: _containers.RepeatedScalarFieldContainer[_source_of_income_and_wealth_pb2.SourceOfIncomeAndWealth]
    sources_of_wealth: _containers.RepeatedScalarFieldContainer[_source_of_income_and_wealth_pb2.SourceOfIncomeAndWealth]
    tax_residencies: _containers.RepeatedCompositeFieldContainer[_tax_residency_pb2.TaxResidency]
    def __init__(self, full_name: _Optional[str] = ..., date_of_birth: _Optional[_Union[_date_pb2.Date, _Mapping]] = ..., country_of_citizenship: _Optional[str] = ..., identification_number: _Optional[str] = ..., identification_document_type: _Optional[_Union[_identification_document_type_pb2.IdentificationDocumentType, str]] = ..., identification_document_expiry_date: _Optional[_Union[_date_pb2.Date, _Mapping]] = ..., physical_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., postal_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., pep_status: _Optional[_Union[_pep_status_pb2.PepStatus, str]] = ..., contact_details: _Optional[_Union[_contact_details_pb2.ContactDetails, _Mapping]] = ..., sources_of_income: _Optional[_Iterable[_Union[_source_of_income_and_wealth_pb2.SourceOfIncomeAndWealth, str]]] = ..., sources_of_wealth: _Optional[_Iterable[_Union[_source_of_income_and_wealth_pb2.SourceOfIncomeAndWealth, str]]] = ..., tax_residencies: _Optional[_Iterable[_Union[_tax_residency_pb2.TaxResidency, _Mapping]]] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as _method_options_pb2
from meshtrade.type.v1 import sorting_pb2 as _sorting_pb2
from meshtrade.type.v1 import token_pb2 as _token_pb2
from meshtrade.wallet.account.v1 import account_pb2 as _account_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAccountRequest(_message.Message):
    __slots__ = ("account",)
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    account: _account_pb2.Account
    def __init__(self, account: _Optional[_Union[_account_pb2.Account, _Mapping]] = ...) -> None: ...

class UpdateAccountRequest(_message.Message):
    __slots__ = ("account",)
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    account: _account_pb2.Account
    def __init__(self, account: _Optional[_Union[_account_pb2.Account, _Mapping]] = ...) -> None: ...

class OpenAccountRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class OpenAccountResponse(_message.Message):
    __slots__ = ("ledger_transaction",)
    LEDGER_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    ledger_transaction: str
    def __init__(self, ledger_transaction: _Optional[str] = ...) -> None: ...

class AddSignatoriesToAccountRequest(_message.Message):
    __slots__ = ("name", "users")
    NAME_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    name: str
    users: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., users: _Optional[_Iterable[str]] = ...) -> None: ...

class AddSignatoriesToAccountResponse(_message.Message):
    __slots__ = ("ledger_transaction",)
    LEDGER_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    ledger_transaction: str
    def __init__(self, ledger_transaction: _Optional[str] = ...) -> None: ...

class RemoveSignatoriesFromAccountRequest(_message.Message):
    __slots__ = ("name", "users")
    NAME_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    name: str
    users: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., users: _Optional[_Iterable[str]] = ...) -> None: ...

class RemoveSignatoriesFromAccountResponse(_message.Message):
    __slots__ = ("ledger_transaction",)
    LEDGER_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    ledger_transaction: str
    def __init__(self, ledger_transaction: _Optional[str] = ...) -> None: ...

class GetAccountRequest(_message.Message):
    __slots__ = ("name", "populate_ledger_data")
    NAME_FIELD_NUMBER: _ClassVar[int]
    POPULATE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    populate_ledger_data: bool
    def __init__(self, name: _Optional[str] = ..., populate_ledger_data: bool = ...) -> None: ...

class GetAccountByNumberRequest(_message.Message):
    __slots__ = ("account_number", "populate_ledger_data")
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    POPULATE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    account_number: str
    populate_ledger_data: bool
    def __init__(self, account_number: _Optional[str] = ..., populate_ledger_data: bool = ...) -> None: ...

class ListAccountsRequest(_message.Message):
    __slots__ = ("sorting", "populate_ledger_data")
    class Sorting(_message.Message):
        __slots__ = ("field", "order")
        FIELD_FIELD_NUMBER: _ClassVar[int]
        ORDER_FIELD_NUMBER: _ClassVar[int]
        field: str
        order: _sorting_pb2.SortingOrder
        def __init__(self, field: _Optional[str] = ..., order: _Optional[_Union[_sorting_pb2.SortingOrder, str]] = ...) -> None: ...
    SORTING_FIELD_NUMBER: _ClassVar[int]
    POPULATE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    sorting: ListAccountsRequest.Sorting
    populate_ledger_data: bool
    def __init__(self, sorting: _Optional[_Union[ListAccountsRequest.Sorting, _Mapping]] = ..., populate_ledger_data: bool = ...) -> None: ...

class ListAccountsResponse(_message.Message):
    __slots__ = ("accounts",)
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_account_pb2.Account]
    def __init__(self, accounts: _Optional[_Iterable[_Union[_account_pb2.Account, _Mapping]]] = ...) -> None: ...

class SearchAccountsRequest(_message.Message):
    __slots__ = ("sorting", "display_name", "populate_ledger_data")
    class Sorting(_message.Message):
        __slots__ = ("field", "order")
        FIELD_FIELD_NUMBER: _ClassVar[int]
        ORDER_FIELD_NUMBER: _ClassVar[int]
        field: str
        order: _sorting_pb2.SortingOrder
        def __init__(self, field: _Optional[str] = ..., order: _Optional[_Union[_sorting_pb2.SortingOrder, str]] = ...) -> None: ...
    SORTING_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    POPULATE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    sorting: SearchAccountsRequest.Sorting
    display_name: str
    populate_ledger_data: bool
    def __init__(self, sorting: _Optional[_Union[SearchAccountsRequest.Sorting, _Mapping]] = ..., display_name: _Optional[str] = ..., populate_ledger_data: bool = ...) -> None: ...

class SearchAccountsResponse(_message.Message):
    __slots__ = ("accounts",)
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    accounts: _containers.RepeatedCompositeFieldContainer[_account_pb2.Account]
    def __init__(self, accounts: _Optional[_Iterable[_Union[_account_pb2.Account, _Mapping]]] = ...) -> None: ...

class RegisterTokensToAccountRequest(_message.Message):
    __slots__ = ("name", "tokens")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TOKENS_FIELD_NUMBER: _ClassVar[int]
    name: str
    tokens: _containers.RepeatedCompositeFieldContainer[_token_pb2.Token]
    def __init__(self, name: _Optional[str] = ..., tokens: _Optional[_Iterable[_Union[_token_pb2.Token, _Mapping]]] = ...) -> None: ...

class RegisterTokensToAccountResponse(_message.Message):
    __slots__ = ("ledger_transaction",)
    LEDGER_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    ledger_transaction: str
    def __init__(self, ledger_transaction: _Optional[str] = ...) -> None: ...

class DeregisterTokensFromAccountRequest(_message.Message):
    __slots__ = ("name", "tokens")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TOKENS_FIELD_NUMBER: _ClassVar[int]
    name: str
    tokens: _containers.RepeatedCompositeFieldContainer[_token_pb2.Token]
    def __init__(self, name: _Optional[str] = ..., tokens: _Optional[_Iterable[_Union[_token_pb2.Token, _Mapping]]] = ...) -> None: ...

class DeregisterTokensFromAccountResponse(_message.Message):
    __slots__ = ("ledger_transaction",)
    LEDGER_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    ledger_transaction: str
    def __init__(self, ledger_transaction: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.market_data.price.v1 import price_pb2 as meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2
from meshtrade.market_data.price.v1 import service_pb2 as meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2


class PriceServiceStub(object):
    """
    PriceService provides market data pricing information.

    This service enables retrieval of current market prices for token pairs,
    supporting trading decisions and portfolio valuation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCurrentPriceByTokenPair = channel.unary_unary(
                '/meshtrade.market_data.price.v1.PriceService/GetCurrentPriceByTokenPair',
                request_serializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2.GetCurrentPriceByTokenPairRequest.SerializeToString,
                response_deserializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2.Price.FromString,
                _registered_method=True)


class PriceServiceServicer(object):
    """
    PriceService provides market data pricing information.

    This service enables retrieval of current market prices for token pairs,
    supporting trading decisions and portfolio valuation.
    """

    def GetCurrentPriceByTokenPair(self, request, context):
        """
        Retrieves the current price for a specified token pair.

        Returns the mid-market price for the base token denominated in the quote token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PriceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCurrentPriceByTokenPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentPriceByTokenPair,
                    request_deserializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2.GetCurrentPriceByTokenPairRequest.FromString,
                    response_serializer=meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2.Price.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.market_data.price.v1.PriceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.market_data.price.v1.PriceService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PriceService(object):
    """
    PriceService provides market data pricing information.

    This service enables retrieval of current market prices for token pairs,
    supporting trading decisions and portfolio valuation.
    """

    @staticmethod
    def GetCurrentPriceByTokenPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.market_data.price.v1.PriceService/GetCurrentPriceByTokenPair',
            meshtrade_dot_market__data_dot_price_dot_v1_dot_service__pb2.GetCurrentPriceByTokenPairRequest.SerializeToString,
            meshtrade_dot_market__data_dot_price_dot_v1_dot_price__pb2.Price.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/role/v1/role.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/role/v1/role.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n meshtrade/iam/role/v1/role.proto\x12\x15meshtrade.iam.role.v1*\xe9\t\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x11ROLE_WALLET_ADMIN\x10\xc0\x84=\x12\x18\n\x12ROLE_WALLET_VIEWER\x10\xc1\x84=\x12\x1f\n\x19ROLE_WALLET_ACCOUNT_ADMIN\x10\xc2\x84=\x12 \n\x1aROLE_WALLET_ACCOUNT_VIEWER\x10\xc3\x84=\x12\x1b\n\x15ROLE_COMPLIANCE_ADMIN\x10\x80\x89z\x12\x1c\n\x16ROLE_COMPLIANCE_VIEWER\x10\x81\x89z\x12\"\n\x1cROLE_COMPLIANCE_CLIENT_ADMIN\x10\x82\x89z\x12#\n\x1dROLE_COMPLIANCE_CLIENT_VIEWER\x10\x83\x89z\x12\x15\n\x0eROLE_IAM_ADMIN\x10\xc0\x8d\xb7\x01\x12\x16\n\x0fROLE_IAM_VIEWER\x10\xc1\x8d\xb7\x01\x12\x1e\n\x17ROLE_IAM_API_USER_ADMIN\x10\xc2\x8d\xb7\x01\x12\x1f\n\x18ROLE_IAM_API_USER_VIEWER\x10\xc3\x8d\xb7\x01\x12\x1b\n\x14ROLE_IAM_GROUP_ADMIN\x10\xc4\x8d\xb7\x01\x12\x1c\n\x15ROLE_IAM_GROUP_VIEWER\x10\xc5\x8d\xb7\x01\x12\x1a\n\x13ROLE_IAM_USER_ADMIN\x10\xc6\x8d\xb7\x01\x12\x1b\n\x14ROLE_IAM_USER_VIEWER\x10\xc7\x8d\xb7\x01\x12\"\n\x1bROLE_IAM_USER_PROFILE_ADMIN\x10\xc8\x8d\xb7\x01\x12#\n\x1cROLE_IAM_USER_PROFILE_VIEWER\x10\xc9\x8d\xb7\x01\x12\x18\n\x11ROLE_STUDIO_ADMIN\x10\x80\x92\xf4\x01\x12\x19\n\x12ROLE_STUDIO_VIEWER\x10\x81\x92\xf4\x01\x12#\n\x1cROLE_STUDIO_INSTRUMENT_ADMIN\x10\x82\x92\xf4\x01\x12$\n\x1dROLE_STUDIO_INSTRUMENT_VIEWER\x10\x83\x92\xf4\x01\x12\x19\n\x12ROLE_TRADING_ADMIN\x10\xc0\x96\xb1\x02\x12\x1a\n\x13ROLE_TRADING_VIEWER\x10\xc1\x96\xb1\x02\x12%\n\x1eROLE_TRADING_LIMIT_ORDER_ADMIN\x10\xc2\x96\xb1\x02\x12&\n\x1fROLE_TRADING_LIMIT_ORDER_VIEWER\x10\xc3\x96\xb1\x02\x12\x1b\n\x14ROLE_REPORTING_ADMIN\x10\x80\x9b\xee\x02\x12\x1c\n\x15ROLE_REPORTING_VIEWER\x10\x81\x9b\xee\x02\x12\x18\n\x11ROLE_LEDGER_ADMIN\x10\xc0\x9f\xab\x03\x12\x19\n\x12ROLE_LEDGER_VIEWER\x10\xc1\x9f\xab\x03\x12$\n\x1dROLE_LEDGER_TRANSACTION_ADMIN\x10\xc2\x9f\xab\x03\x12%\n\x1eROLE_LEDGER_TRANSACTION_VIEWER\x10\xc3\x9f\xab\x03\x12\x1d\n\x16ROLE_MARKET_DATA_ADMIN\x10\x80\xa4\xe8\x03\x12\x1e\n\x17ROLE_MARKET_DATA_VIEWER\x10\x81\xa4\xe8\x03\x12#\n\x1cROLE_MARKET_DATA_PRICE_ADMIN\x10\x82\xa4\xe8\x03\x12$\n\x1dROLE_MARKET_DATA_PRICE_VIEWER\x10\x83\xa4\xe8\x03\x12*\n#ROLE_TESTING_LEDGER_TOKEN_TAP_ADMIN\x10\xc0\xa8\xa5\x04\x12+\n$ROLE_TESTING_LEDGER_TOKEN_TAP_VIEWER\x10\xc1\xa8\xa5\x04\x42O\n\x1c\x63o.meshtrade.api.iam.role.v1Z/github.com/meshtrade/api/go/iam/role/v1;role_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.role.v1.role_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034co.meshtrade.api.iam.role.v1Z/github.com/meshtrade/api/go/iam/role/v1;role_v1'
  _globals['_ROLE']._serialized_start=60
  _globals['_ROLE']._serialized_end=1317
# @@protoc_insertion_point(module_scope)



from .ledger_pb2 import Ledger

_ledger_decimal_places: dict[Ledger, int] = {
    Ledger.LEDGER_STELLAR: 7,
    Ledger.LEDGER_SA_STOCK_BROKERS: 2,
}


class UnsupportedLedgerError(Exception):
    """Exception raised for unsupported Ledger values."""

    def __init__(self, ledger: Ledger):
        self.ledger = ledger
        message = f"Unsupported Ledger: {ledger}"
        super().__init__(message)


def get_ledger_no_decimal_places(ledger: Ledger) -> int:
    """
    Returns the number of decimal places supported by the given Ledger
    """
    if ledger in _ledger_decimal_places:
        return _ledger_decimal_places[ledger]
    else:
        raise UnsupportedLedgerError(ledger)


def ledger_to_pretty_string(ledger: Ledger) -> str:
    """Convert the Ledger enum value to a human-readable network name.

    This method provides user-friendly names for each blockchain network/ledger type.

    Args:
        ledger: The Ledger enum value

    Returns:
        A human-readable network name string, or "Unknown" for invalid/unrecognized values

    Example:
        >>> ledger_to_pretty_string(Ledger.LEDGER_STELLAR)
        'Stellar'
        >>> ledger_to_pretty_string(Ledger.LEDGER_ETHEREUM)
        'Ethereum'
        >>> ledger_to_pretty_string(Ledger.LEDGER_UNSPECIFIED)
        'Unspecified'
    """
    if ledger == Ledger.LEDGER_STELLAR:
        return "Stellar"
    elif ledger == Ledger.LEDGER_ETHEREUM:
        return "Ethereum"
    elif ledger == Ledger.LEDGER_BITCOIN:
        return "Bitcoin"
    elif ledger == Ledger.LEDGER_LITECOIN:
        return "Litecoin"
    elif ledger == Ledger.LEDGER_XRP:
        return "XRP"
    elif ledger == Ledger.LEDGER_SA_STOCK_BROKERS:
        return "SA Stock Brokers"
    elif ledger == Ledger.LEDGER_NULL:
        return "Null"
    elif ledger == Ledger.LEDGER_UNSPECIFIED:
        return "Unspecified"
    else:
        return "Unknown"


def ledger_is_valid(ledger: Ledger) -> bool:
    """Check if ledger value is valid (within enum range).

    Args:
        ledger: The Ledger enum value to check

    Returns:
        True if the ledger is a valid enum value, False otherwise

    Example:
        >>> ledger_is_valid(Ledger.LEDGER_STELLAR)
        True
        >>> ledger_is_valid(999)  # Invalid enum value
        False
    """
    return ledger in Ledger.values()


def ledger_is_valid_and_defined(ledger: Ledger) -> bool:
    """Check if ledger is valid and not UNSPECIFIED.

    Args:
        ledger: The Ledger enum value to check

    Returns:
        True if the ledger is valid and not LEDGER_UNSPECIFIED, False otherwise

    Example:
        >>> ledger_is_valid_and_defined(Ledger.LEDGER_STELLAR)
        True
        >>> ledger_is_valid_and_defined(Ledger.LEDGER_UNSPECIFIED)
        False
    """
    return ledger_is_valid(ledger) and ledger != Ledger.LEDGER_UNSPECIFIED



"""
Common configuration utilities and constants for Meshtrade gRPC clients.
"""

DEFAULT_GRPC_URL = "production-service-mesh-api-gateway-lb-frontend.mesh.trade"
DEFAULT_GRPC_PORT = 443
DEFAULT_TLS = True

# gRPC metadata constants
API_KEY_HEADER = "x-api-key"
COOKIE_HEADER_KEY = "cookie"
GROUP_HEADER_KEY = "x-group"
ACCESS_TOKEN_PREFIX = "AccessToken="


def create_auth_metadata(api_key: str, group: str) -> list[tuple[str, str]]:
    """Create authentication metadata for gRPC requests.

    Args:
        api_key: The API key
        group: The group resource name in format groups/{group_id}

    Returns:
        List of metadata header tuples for authentication
    """
    return [
        (API_KEY_HEADER, api_key),
        (GROUP_HEADER_KEY, group),  # Send full groups/uuid format in header
    ]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/client.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/client.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.compliance.client.v1 import company_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_company__pb2
from meshtrade.compliance.client.v1 import fund_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_fund__pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_natural__person__pb2
from meshtrade.compliance.client.v1 import trust_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_trust__pb2
from meshtrade.compliance.client.v1 import verification_status_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_verification__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+meshtrade/compliance/client/v1/client.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a,meshtrade/compliance/client/v1/company.proto\x1a)meshtrade/compliance/client/v1/fund.proto\x1a\x33meshtrade/compliance/client/v1/natural_person.proto\x1a*meshtrade/compliance/client/v1/trust.proto\x1a\x38meshtrade/compliance/client/v1/verification_status.proto\"\xe4\t\n\x06\x43lient\x12\xbe\x01\n\x04name\x18\x01 \x01(\tB\xa9\x01\xbaH\xa5\x01\xba\x01\xa1\x01\n\x14name.format.optional\x12\x34name must be empty or in the format clients/{ULIDv2}\x1aSsize(this) == 0 || this.matches(\'^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12V\n\x06owners\x18\x03 \x03(\tB>\xbaH;\x92\x01\x38\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!R\x06owners\x12\x30\n\x0c\x64isplay_name\x18\x04 \x01(\tB\r\xbaH\nr\x05\x10\x01\x18\xff\x01\xc8\x01\x01R\x0b\x64isplayName\x12V\n\x0enatural_person\x18\x05 \x01(\x0b\x32-.meshtrade.compliance.client.v1.NaturalPersonH\x00R\rnaturalPerson\x12\x43\n\x07\x63ompany\x18\x06 \x01(\x0b\x32\'.meshtrade.compliance.client.v1.CompanyH\x00R\x07\x63ompany\x12:\n\x04\x66und\x18\x07 \x01(\x0b\x32$.meshtrade.compliance.client.v1.FundH\x00R\x04\x66und\x12=\n\x05trust\x18\x08 \x01(\x0b\x32%.meshtrade.compliance.client.v1.TrustH\x00R\x05trust\x12p\n\x13verification_status\x18\t \x01(\x0e\x32\x32.meshtrade.compliance.client.v1.VerificationStatusB\x0b\xbaH\x08\x82\x01\x02\x10\x01\xc8\x01\x01R\x12verificationStatus\x12\x85\x02\n\x16verification_authority\x18\n \x01(\tB\xcd\x01\xbaH\xc9\x01\xba\x01\xc5\x01\n&verification_authority.format.optional\x12\x46verification_authority must be empty or in the format clients/{ULIDv2}\x1aSsize(this) == 0 || this.matches(\'^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x15verificationAuthority\x12G\n\x11verification_date\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10verificationDate\x12P\n\x16next_verification_date\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14nextVerificationDateB\x0e\n\x0clegal_personBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_CLIENT'].fields_by_name['name']._loaded_options = None
  _globals['_CLIENT'].fields_by_name['name']._serialized_options = b'\272H\245\001\272\001\241\001\n\024name.format.optional\0224name must be empty or in the format clients/{ULIDv2}\032Ssize(this) == 0 || this.matches(\'^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_CLIENT'].fields_by_name['owner']._loaded_options = None
  _globals['_CLIENT'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_CLIENT'].fields_by_name['owners']._loaded_options = None
  _globals['_CLIENT'].fields_by_name['owners']._serialized_options = b'\272H;\222\0018\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!'
  _globals['_CLIENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_CLIENT'].fields_by_name['display_name']._serialized_options = b'\272H\nr\005\020\001\030\377\001\310\001\001'
  _globals['_CLIENT'].fields_by_name['verification_status']._loaded_options = None
  _globals['_CLIENT'].fields_by_name['verification_status']._serialized_options = b'\272H\010\202\001\002\020\001\310\001\001'
  _globals['_CLIENT'].fields_by_name['verification_authority']._loaded_options = None
  _globals['_CLIENT'].fields_by_name['verification_authority']._serialized_options = b'\272H\311\001\272\001\305\001\n&verification_authority.format.optional\022Fverification_authority must be empty or in the format clients/{ULIDv2}\032Ssize(this) == 0 || this.matches(\'^clients/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_CLIENT']._serialized_start=386
  _globals['_CLIENT']._serialized_end=1638
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/market_order/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/market_order/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.trading.market_order.v1 import market_order_pb2 as meshtrade_dot_trading_dot_market__order_dot_v1_dot_market__order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/meshtrade/trading/market_order/v1/service.proto\x12!meshtrade.trading.market_order.v1\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x34meshtrade/trading/market_order/v1/market_order.proto\"/\n\x15GetMarketOrderRequest\x12\x16\n\x06number\x18\x01 \x01(\tR\x06number2\xa5\x01\n\x12MarketOrderService\x12\x8e\x01\n\x0eGetMarketOrder\x12\x38.meshtrade.trading.market_order.v1.GetMarketOrderRequest\x1a..meshtrade.trading.market_order.v1.MarketOrder\"\x12\xb2\xb5\x18\x0e\x08\x01\x10\x02\x1a\x08\xc0\x96\xb1\x02\xc1\x96\xb1\x02\x42o\n(co.meshtrade.api.trading.market_order.v1ZCgithub.com/meshtrade/api/go/trading/market_order/v1;market_order_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.market_order.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(co.meshtrade.api.trading.market_order.v1ZCgithub.com/meshtrade/api/go/trading/market_order/v1;market_order_v1'
  _globals['_MARKETORDERSERVICE'].methods_by_name['GetMarketOrder']._loaded_options = None
  _globals['_MARKETORDERSERVICE'].methods_by_name['GetMarketOrder']._serialized_options = b'\262\265\030\016\010\001\020\002\032\010\300\226\261\002\301\226\261\002'
  _globals['_GETMARKETORDERREQUEST']._serialized_start=197
  _globals['_GETMARKETORDERREQUEST']._serialized_end=244
  _globals['_MARKETORDERSERVICE']._serialized_start=247
  _globals['_MARKETORDERSERVICE']._serialized_end=412
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as _method_options_pb2
from meshtrade.trading.limit_order.v1 import limit_order_pb2 as _limit_order_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateLimitOrderRequest(_message.Message):
    __slots__ = ("limit_order",)
    LIMIT_ORDER_FIELD_NUMBER: _ClassVar[int]
    limit_order: _limit_order_pb2.LimitOrder
    def __init__(self, limit_order: _Optional[_Union[_limit_order_pb2.LimitOrder, _Mapping]] = ...) -> None: ...

class CancelLimitOrderRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetLimitOrderRequest(_message.Message):
    __slots__ = ("name", "live_ledger_data")
    NAME_FIELD_NUMBER: _ClassVar[int]
    LIVE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    live_ledger_data: bool
    def __init__(self, name: _Optional[str] = ..., live_ledger_data: bool = ...) -> None: ...

class GetLimitOrderByExternalReferenceRequest(_message.Message):
    __slots__ = ("external_reference", "live_ledger_data")
    EXTERNAL_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    LIVE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    external_reference: str
    live_ledger_data: bool
    def __init__(self, external_reference: _Optional[str] = ..., live_ledger_data: bool = ...) -> None: ...

class ListLimitOrdersRequest(_message.Message):
    __slots__ = ("live_ledger_data",)
    LIVE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    live_ledger_data: bool
    def __init__(self, live_ledger_data: bool = ...) -> None: ...

class ListLimitOrdersResponse(_message.Message):
    __slots__ = ("limit_orders",)
    LIMIT_ORDERS_FIELD_NUMBER: _ClassVar[int]
    limit_orders: _containers.RepeatedCompositeFieldContainer[_limit_order_pb2.LimitOrder]
    def __init__(self, limit_orders: _Optional[_Iterable[_Union[_limit_order_pb2.LimitOrder, _Mapping]]] = ...) -> None: ...

class SearchLimitOrdersRequest(_message.Message):
    __slots__ = ("token", "account", "states", "live_ledger_data")
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    STATES_FIELD_NUMBER: _ClassVar[int]
    LIVE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    token: str
    account: str
    states: _containers.RepeatedScalarFieldContainer[_limit_order_pb2.LimitOrderState]
    live_ledger_data: bool
    def __init__(self, token: _Optional[str] = ..., account: _Optional[str] = ..., states: _Optional[_Iterable[_Union[_limit_order_pb2.LimitOrderState, str]]] = ..., live_ledger_data: bool = ...) -> None: ...

class SearchLimitOrdersResponse(_message.Message):
    __slots__ = ("limit_orders",)
    LIMIT_ORDERS_FIELD_NUMBER: _ClassVar[int]
    limit_orders: _containers.RepeatedCompositeFieldContainer[_limit_order_pb2.LimitOrder]
    def __init__(self, limit_orders: _Optional[_Iterable[_Union[_limit_order_pb2.LimitOrder, _Mapping]]] = ...) -> None: ...

class MonitorLimitOrderRequest(_message.Message):
    __slots__ = ("name", "external_reference", "live_ledger_data")
    NAME_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    LIVE_LEDGER_DATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    external_reference: str
    live_ledger_data: bool
    def __init__(self, name: _Optional[str] = ..., external_reference: _Optional[str] = ..., live_ledger_data: bool = ...) -> None: ...
